#include <Ethernet.h>
#include <EthernetUdp.h>
#include <SPI.h>    
#include <OSCBundle.h>
#include <Encoder.h>

// #define LEFT true

// SERVER
IPAddress outIp(192, 168, 2, 226); //destination IP

// NETWORK CONFIGURATION 
#ifdef LEFT

int outPort = 9999;
byte mac[] = { 0x90, 0xa2, 0xda, 0x0e, 0xd2, 0xc4 }; 
IPAddress ip(192, 168, 2, 77); //the Arduino's IP
char* name = "left"; // the identifier of the arduino

#else

int outPort = 9998;
byte mac[] = { 0x90, 0xa2, 0xda, 0x0e, 0xd2, 0xc3 }; 
IPAddress ip(192, 168, 2, 78); //the Arduino's IP
char* name = "right"; // the identifier of the arduino

#endif


// STREAM CONFIGURATION
EthernetUDP Udp;

// PIN CONFIGURATION
Encoder myEnc(2, 3); //   Best Performance: both pins have interrupt capability
int buttonPin[] = {6,7, 8,9}; // digital
int potiPin = 0; // analog

void setup() {
//  Serial.begin(19200);

  Ethernet.begin(mac,ip); // define IP
  Udp.begin(outPort);  // open socket
  
  int mode = INPUT_PULLUP;
  
  pinMode(buttonPin[0], mode);
  pinMode(buttonPin[1], mode);
  pinMode(buttonPin[2], mode);
  pinMode(buttonPin[3], mode);

}

void loop(){
    OSCBundle bndl;

    //BOSCBundle's add' returns the OSCMessage so the message's 'add' can be composed together
    bndl.add("/name").add(name);
    bndl.add("/rotary").add((int32_t)myEnc.read()); // you can rotate from -2billion to +2billion
    bndl.add("/poti").add((int32_t)analogRead(potiPin));  // 0 - 1023
 
    boolean high = LOW; // flip because of INPUT_PULLUP
    bndl.add("/button0").add(digitalRead(buttonPin[0])==high?1:0);
    bndl.add("/button1").add(digitalRead(buttonPin[1])==high?1:0);
    bndl.add("/button2").add(digitalRead(buttonPin[2])==high?1:0);
    bndl.add("/button3").add(digitalRead(buttonPin[3])==high?1:0);

//    Serial.write("Ack");

    Udp.beginPacket(outIp, outPort);        
    bndl.send(Udp); // send the bytes to the SLIP stream
    Udp.endPacket(); // mark the end of the OSC Packet

    bndl.empty(); // empty the bundle to free room for a new one

}
